@@ -41,7 +41,7 @@ import sys
 import logzero
 from logzero import logger as log
 
-from . import argparse_actions, binning, utils
+from . import argparse_tools, binning, utils
 
 try:
     from .version import version  # type: ignore
@@ -52,7 +52,21 @@ except ImportError:
 def decode_arguments(args):
     """Decode CLI arguments."""
     parser = argparse.ArgumentParser(
-        allow_abbrev=False, formatter_class=argparse.ArgumentDefaultsHelpFormatter
+        allow_abbrev=False,
+        formatter_class=argparse_tools.RawDefaultsFormatter,
+        description=(
+            "This module creates histograms that can be used to estimate "
+            "the PID efficiency of a user's sample."
+            "\n\n"
+            "Reading all the relevant calibration files can take a long time. "
+            "When running a configuration for the first time, we recommend using "
+            "the --max-files 1 option. This will limit PIDCalib2 to reading just "
+            "a single calibration file. Such a test will reveal any problems "
+            "with, e.g., missing variables quickly. Keep in mind that you might "
+            "get a warning about empty bins in the total histogram as you are "
+            "reading a small subset of the calibration data. For the purposes of "
+            "a quick test, this warning can be safely ignored."
+        ),
     )
     parser.add_argument(
         "-s",
@@ -120,7 +134,7 @@ def decode_arguments(args):
     parser.add_argument(
         "-l",
         "--list",
-        action=argparse_actions.ListValidAction,
+        action=argparse_tools.ListValidAction,
         help="list all [configs, aliases]",
     )
     parser.add_argument(
