@@ -13,6 +13,7 @@ import math
 import os
 from pathlib import Path
 
+import uproot
 import pytest
 
 from pidcalib2 import pid_data
@@ -35,6 +36,21 @@ def test_root_to_dataframe():
         == 18400
     )
 
+    with pytest.raises(uproot.exceptions.KeyInFileError):
+        pid_data.root_to_dataframe(
+            "root://eoslhcb.cern.ch//eos/lhcb/grid/prod/lhcb/LHCb/Collision15/PIDCALIB.ROOT/00064787/0000/00064787_00000037_1.pidcalib.root",  # noqa: E501
+            ["DSt_PiMTuple/DecayTree", "DSt_PiPTuple/DecayTree"],
+            ["probe_PIDnu"],
+        )
+
+    with pytest.raises(uproot.exceptions.KeyInFileError):
+        pid_data.root_to_dataframe(
+            "root://eoslhcb.cern.ch//eos/lhcb/grid/prod/lhcb/LHCb/Collision15/PIDCALIB.ROOT/00064787/0000/00064787_00000037_1.pidcalib.root",  # noqa: E501
+            ["DSt_PiMTuple/DecayTree", "DSt_PiPTuple/DecayTree"],
+            ["DLLnu"],
+            True,
+        )
+
 
 def test_get_tree_paths():
     assert pid_data.get_tree_paths("Pi", "26") == ["DecayTree"]
@@ -82,6 +98,27 @@ def test_get_relevant_branch_names():
         "special_var": "special_var",
     }
 
+    with pytest.raises(KeyError):
+        pid_data.get_relevant_branch_names(["DLLp > 4 & probe_PIDp > 4"], ["P", "ETA"])
+
+    assert pid_data.get_relevant_branch_names(
+        ["test_DLL != 4"], ["special_var"], ["raw_var > 0"]
+    ) == {
+        "sWeight": "probe_sWeight",
+        "test_DLL": "test_DLL",
+        "special_var": "special_var",
+        "raw_var": "raw_var",
+    }
+
+    assert pid_data.get_relevant_branch_names(
+        ["test_DLL != 4"], ["special_var"], ["P > 1000"]
+    ) == {
+        "sWeight": "probe_sWeight",
+        "test_DLL": "test_DLL",
+        "special_var": "special_var",
+        "P": "probe_P",
+    }
+
 
 def test_dataframe_from_local_file(test_path):
     df = pid_data.dataframe_from_local_file(
