@@ -66,13 +66,24 @@ def create_eff_histograms(hists: Dict[str, bh.Histogram]) -> Dict[str, bh.Histog
                 "You might want to change the binning."
             )
         )
-        log.debug(hists["total"].values(flow=False))
+        log.debug("Total histo: \n%s", hists["total"].values(flow=False))
 
         # Replace zeros with NaNs which suppresses duplicate Numpy warnings
         hist_total_nan = hists["total"].values()
         hist_total_nan[hist_total_nan == 0] = np.nan
         hists["total"].view().value = hist_total_nan  # type: ignore
 
+    emptyish_bins = np.count_nonzero(hists["total"].values(flow=False) < 10)
+    if emptyish_bins:
+        log.warning(
+            (
+                f"There are {emptyish_bins} non-empty bins with < 10 events "
+                "in the total histogram! You might want to change the binning."
+            )
+        )
+        if not zero_bins:
+            log.debug("Total histo: \n%s", hists["total"].values(flow=False))
+
     for name in list(hists):
         if name.startswith("passing_"):
             eff_name = name.replace("passing_", "eff_", 1)
@@ -100,7 +111,18 @@ def create_eff_histograms(hists: Dict[str, bh.Histogram]) -> Dict[str, bh.Histog
                         "efficiency histogram! You might want to change the binning."
                     )
                 )
-                log.debug(hists[eff_name].values(flow=False))
+
+            too_large_bins = np.count_nonzero(hists[eff_name].values(flow=False) > 1)
+            if too_large_bins:
+                log.warning(
+                    (
+                        f"There are {too_large_bins} bins > 1 in the '{eff_name}' "
+                        "efficiency histogram! You might want to change the binning."
+                    )
+                )
+
+            if negative_bins or too_large_bins:
+                log.debug("Efficiency histo: \n%s", hists[eff_name].values(flow=False))
 
     if zero_bins:
         # Return the zeros that were temporarily replaced by NaNs
@@ -294,8 +316,8 @@ def create_hist_filename(
 def binomial_uncertainty(
     num_pass: Union[float, np.ndarray],
     num_total: Union[float, np.ndarray],
-    err_pass_sq: Union[float, np.ndarray],
-    err_tot_sq: Union[float, np.ndarray],
+    err_pass_sq: Union[float, np.ndarray, None] = None,
+    err_tot_sq: Union[float, np.ndarray, None] = None,
 ) -> float:
     """Return the uncertainty of binomial experiments.
 
@@ -311,10 +333,14 @@ def binomial_uncertainty(
         num_pass: Number of passing events.
         num_total: Total number of events.
         err_pass_sq: Squared uncertainty on the number of passing events (sum
-            of squares of the event weights).
+            of squares of the event weights). Can be ommited for unweighted events.
         err_tot_sq: Squared uncertainty on the number of total events (sum of
-            squares of the event weights).
+            squares of the event weights). Can be ommited for unweighted events.
     """
+    if err_pass_sq is None:
+        err_pass_sq = num_pass
+    if err_tot_sq is None:
+        err_tot_sq = num_total
     prob = num_pass / num_total
     prob_sq = prob ** 2  # type: ignore
     num_total_sq = num_total ** 2  # type: ignore
